@@ -446,6 +446,10 @@ void KcmGtk::save()
 	stream << "\n";
 	stream << "gtk-theme-name=\"" << themeNameShort << "\"\n";
 	stream << "gtk-font-name=\"" << fontName << "\"\n";
+	stream << "gtk-icon-theme-name=\"tdegtk-icon-theme\"\n";
+	stream << "gtk-fallback-icon-theme-name=\"tdegtk-fallback-icon-theme\"\n";
+	stream << "\n";
+	stream << "include \"~/.gtkrc\"\n";
 	
 	if (widget->emacsBox->isChecked())
 		stream << "gtk-key-theme-name=\"Emacs\"\n";
