@@ -222,9 +222,9 @@ draw_shadow(GtkStyle     *style,
 	}
 	
 	/* The remainder of this function was borrowed from the "Metal" theme/
-	   I don't really want to use Qt to draw these frames as there are too
+	   I don't really want to use TQt to draw these frames as there are too
 	   many of them (it would slow down the theme engine even more).
-	   TODO: Make them use the Qt color palette */
+	   TODO: Make them use the TQt color palette */
 	 
 	switch (shadow_type)
 	{
@@ -887,10 +887,10 @@ draw_box(GtkStyle * style,
 			nb = (GtkNotebook *)widget;
 			nbpages = g_list_length(nb->children);
 			/* THIS IS WHAT WORKS NOW --
-				Tabs and tabbarbase will be drawn properly according to the QT style
-				But the tabs won't be aligned according to QT. GTK+ does not have 
+				Tabs and tabbarbase will be drawn properly according to the TQt style
+				But the tabs won't be aligned according to TQt. GTK+ does not have 
 				an option for alignment of tabs. So if were to do this not only do we have to 
-				calculate the x,y position of the tab ourselves, which is difficult in Qt unless
+				calculate the x,y position of the tab ourselves, which is difficult in TQt unless
 				we are displaying the tab (can be done by subclassing TQTabBar/TQTabWidget)
 				but also have to position the tab bar label ourselves in gtk. 
 			*/
